==> kernel-0.9.1.5.8.3.1-sources.jar: voxeet/com/sdk/models/SubscribeConference.java <==
package voxeet.com.sdk.models;

import com.fasterxml.jackson.annotation.JsonProperty;

import java.util.List;

public class SubscribeConference {

    private long startTimestamp;

    private String conferenceId;

    private String conferenceAlias;

    private List<SdkParticipant> participants;

    @JsonProperty("isLive")
    private boolean live;

    private String userId;

    private long conferenceTimestamp;

    private String type;

    public long getStartTimestamp() {
        return startTimestamp;
    }

    public void setStartTimestamp(long startTimestamp) {
        this.startTimestamp = startTimestamp;
    }

    public String getConferenceId() {
        return conferenceId;
    }

    public void setConferenceId(String conferenceId) {
        this.conferenceId = conferenceId;
    }

    public String getConferenceAlias() {
        return conferenceAlias;
    }

    public void setConferenceAlias(String conferenceAlias) {
        this.conferenceAlias = conferenceAlias;
    }

    public List<SdkParticipant> getParticipants() {
        return participants;
    }

    public void setParticipants(List<SdkParticipant> participants) {
        this.participants = participants;
    }

    public boolean isLive() {
        return live;
    }

    public void setLive(boolean live) {
        this.live = live;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public long getConferenceTimestamp() {
        return conferenceTimestamp;
    }

    public void setConferenceTimestamp(long conferenceTimestamp) {
        this.conferenceTimestamp = conferenceTimestamp;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }
}

==> kernel-1.4-sources.jar: voxeet/com/sdk/models/SubscribeConference.java <==
package voxeet.com.sdk.models;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;

import java.util.List;

@JsonIgnoreProperties(ignoreUnknown = true)
public class SubscribeConference {

    private long startTimestamp;

    private String conferenceId;

    private String conferenceAlias;

    private List<SdkParticipant> participants;

    @JsonProperty("isLive")
    private boolean live;

    private String userId;

    private long conferenceTimestamp;

    private String type;

    public long getStartTimestamp() {
        return startTimestamp;
    }

    public void setStartTimestamp(long startTimestamp) {
        this.startTimestamp = startTimestamp;
    }

    public String getConferenceId() {
        return conferenceId;
    }

    public void setConferenceId(String conferenceId) {
        this.conferenceId = conferenceId;
    }

    public String getConferenceAlias() {
        return conferenceAlias;
    }

    public void setConferenceAlias(String conferenceAlias) {
        this.conferenceAlias = conferenceAlias;
    }

    public List<SdkParticipant> getParticipants() {
        return participants;
    }

    public void setParticipants(List<SdkParticipant> participants) {
        this.participants = participants;
    }

    public boolean isLive() {
        return live;
    }

    public void setLive(boolean live) {
        this.live = live;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public long getConferenceTimestamp() {
        return conferenceTimestamp;
    }

    public void setConferenceTimestamp(long conferenceTimestamp) {
        this.conferenceTimestamp = conferenceTimestamp;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }
}
